pub struct RekeyThresholds {
pub max_frames: u64,
pub max_bytes: u64,
pub max_age: Duration,
pub max_previous_keys: usize,
}Expand description
Rekey thresholds and key-retention policy.
Fields
max_frames: u64Trigger rekey when outbound frame count reaches this value.
max_bytes: u64Trigger rekey when outbound plaintext bytes reaches this value.
max_age: DurationTrigger rekey when elapsed time since last rekey reaches this value.
max_previous_keys: usizeNumber of previous keys retained for inbound compatibility.