pub struct SessionAuthConfig { /* private fields */ }Expand description
Session-level handshake authentication configuration.
Implementations
Sourceimpl SessionAuthConfig
impl SessionAuthConfig
Sourcepub fn with_local_identity(self, identity: IdentityKeyPair) -> Self
pub fn with_local_identity(self, identity: IdentityKeyPair) -> Self
Attaches a local identity used to sign native handshake messages.
Sourcepub fn with_peer_identity(self, identity: PeerIdentity) -> Self
pub fn with_peer_identity(self, identity: PeerIdentity) -> Self
Pins the expected remote identity public key.
Sourcepub fn require_peer_authentication(self, require: bool) -> Self
pub fn require_peer_authentication(self, require: bool) -> Self
Requires the remote side to present a valid authenticated handshake.
Sourcepub fn local_identity(&self) -> Option<&IdentityKeyPair>
pub fn local_identity(&self) -> Option<&IdentityKeyPair>
Returns the local identity, if configured.
Sourcepub fn peer_identity(&self) -> Option<PeerIdentity>
pub fn peer_identity(&self) -> Option<PeerIdentity>
Returns the pinned peer identity, if configured.
Sourcepub fn requires_peer_authentication(&self) -> bool
pub fn requires_peer_authentication(&self) -> bool
Returns whether remote handshake authentication is mandatory.